@@ -4,6 +4,16 @@
 
 History
 ============
+v1.4.1 @ 2020-11-24
+---------------------
+- Correlation functions in pyhdust.stats
+- Other small updates
+
+v1.4.0 @ 2020-11-04
+---------------------
+- Multiple small updates
+- Incorporate max(M)==20.0Msun (instead of 14.6Msun)
+
 v1.007 @ 2016-09-16
 ---------------------
 - New ploting 2d routines
